@@ -1,5 +1,6 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+import sys
 from collections import OrderedDict as od
 from itertools import groupby
 
@@ -1181,6 +1182,9 @@ class PostgreSQL(DBInspector):
         enums=True,
         include_fk_deps=False,
     ):
+        if sys.version_info < (3, 0):
+            raise NotImplementedError
+
         from schemainspect import TopologicalSorter
 
         graph, things = {}, {}
